summaryrefslogtreecommitdiffstats
path: root/src/itemdocument.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commite47aaa9b34ffc363d268aca989aab28fdfaf9821 (patch)
tree369b56d21949c574d30f71bdf24bf1e04f5e1877 /src/itemdocument.cpp
parente05894553004a47b1e2f276bedcf5963b57a3932 (diff)
downloadktechlab-e47aaa9b34ffc363d268aca989aab28fdfaf9821.tar.gz
ktechlab-e47aaa9b34ffc363d268aca989aab28fdfaf9821.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktechlab@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/itemdocument.cpp')
-rw-r--r--src/itemdocument.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/itemdocument.cpp b/src/itemdocument.cpp
index 1742094..283eb5f 100644
--- a/src/itemdocument.cpp
+++ b/src/itemdocument.cpp
@@ -494,7 +494,7 @@ TQCanvasItem* ItemDocument::itemAtTop( const TQPoint &pos ) const
else
{
if ( item->rtti() == ItemDocument::RTTI::ConnectorLine )
- return (static_cast<ConnectorLine*>(item))->tqparent();
+ return (static_cast<ConnectorLine*>(item))->parent();
return item;
}
@@ -790,7 +790,7 @@ void ItemDocument::exportToImage()
// widget for the kfiledialog
// It is the bit that says "Crop circuit?"
// Okay need to think of something way better to say here.
// gotme here, KFileDialog makes itself tqparent so tries to destroy cropCheck when it is deleted.
// therefore we use a pointer.
TQString cropMessage;
if ( type() == Document::dt_flowcode )
@@ -790,7 +790,7 @@ void ItemDocument::exportToImage()
// It is the bit that says "Crop circuit?"
// Okay need to think of something way better to say here.
- // gotme here, KFileDialog makes itself tqparent so tries to destroy cropCheck when it is deleted.
+ // gotme here, KFileDialog makes itself parent so tries to destroy cropCheck when it is deleted.
// therefore we use a pointer.
TQString cropMessage;